@@ -505,6 +505,17 @@ class ISD(model.Document):
       styles_to_be_computed.add(spec_style_prop)
       isd_element.set_style(spec_style_prop, element.get_style(spec_style_prop))
 
+    # direction special semantics
+    # https://www.w3.org/TR/ttml2/#style-attribute-direction-special-semantics
+
+    if isinstance(element, model.Region) and \
+        (not element.has_style(styles.StyleProperties.Direction)) and \
+        element.get_style(styles.StyleProperties.WritingMode) in (styles.WritingModeType.lrtb, styles.WritingModeType.rltb):
+      styles_to_be_computed.add(styles.StyleProperties.Direction)
+      direction = styles.DirectionType.ltr if element.get_style(styles.StyleProperties.WritingMode) == styles.WritingModeType.lrtb \
+                  else styles.DirectionType.rtl
+      isd_element.set_style(styles.StyleProperties.Direction, direction)
+
     # inherited styling
 
     if not isinstance(element, (model.Br, model.Text, model.Region)):
@@ -770,10 +781,11 @@ def _make_rw_length(value: numbers.Number) -> styles.LengthType:
     units=styles.LengthType.Units.rw
   )
 
-def _get_writing_mode(isd_element: model.ContentElement) -> styles.WritingModeType:
+def _get_writing_mode(isd_parent: model.ContentElement, isd_element: model.ContentElement) -> styles.WritingModeType:
 
-  while not isinstance(isd_element, ISD.Region):
-    isd_element = isd_element.get_parent()
+  while isd_parent is not None:
+    isd_element = isd_parent
+    isd_parent = isd_element.parent()
 
   return isd_element.get_style(styles.StyleProperties.WritingMode)
 
@@ -1227,7 +1239,7 @@ class StyleProcessors:
 
         if value.style is styles.TextEmphasisType.Style.auto:
 
-          wm: styles.WritingModeType = _get_writing_mode(parent)
+          wm: styles.WritingModeType = _get_writing_mode(parent, element)
 
           if wm in (styles.WritingModeType.tblr, styles.WritingModeType.tbrl):
 
