@@ -41,6 +41,7 @@ import ttconv.scc.reader as scc_reader
 import ttconv.srt.writer as srt_writer
 import ttconv.srt.reader as srt_reader
 import ttconv.stl.reader as stl_reader
+import ttconv.vtt.reader as vtt_reader
 from ttconv.vtt.config import VTTWriterConfiguration
 import ttconv.vtt.writer as vtt_writer
 from ttconv.config import GeneralConfiguration
@@ -49,6 +50,7 @@ from ttconv.imsc.config import IMSCWriterConfiguration
 from ttconv.isd import ISDConfiguration
 from ttconv.scc.config import SccReaderConfiguration
 from ttconv.stl.config import STLReaderConfiguration
+from ttconv.srt.config import SRTWriterConfiguration
 
 LOGGER = logging.getLogger("ttconv")
 
@@ -274,7 +276,7 @@ def convert(args):
     with open(args.config_file) as json_file:
       json_config_data = json.load(json_file)
 
-  general_config = read_config_from_json(GeneralConfiguration, json_config_data)
+  general_config : GeneralConfiguration = read_config_from_json(GeneralConfiguration, json_config_data)
 
   if general_config is not None:
 
@@ -337,6 +339,14 @@ def convert(args):
     with open(inputfile, "r", encoding="utf-8") as f:
       model = srt_reader.to_model(f, None, progress_callback_read)
 
+  elif reader_type is FileTypes.VTT:
+
+    #
+    # Open the file and pass it to the reader
+    #
+    with open(inputfile, "r", encoding="utf-8") as f:
+      model = vtt_reader.to_model(f, None, progress_callback_read)
+
   else:
     if args.itype is not None:
       exit_str = f'Input type {args.itype} is not supported'
@@ -346,6 +356,12 @@ def convert(args):
     LOGGER.error(exit_str)
     sys.exit(exit_str)
 
+  #
+  # apply document language
+  #
+  if general_config is not None and general_config.document_lang is not None:
+    model.set_lang(general_config.document_lang)
+
   if writer_type is FileTypes.TTML:
     #
     # Read the config
@@ -366,7 +382,7 @@ def convert(args):
     #
     # Read the config
     #
-    writer_config = read_config_from_json(ISDConfiguration, json_config_data)
+    writer_config = read_config_from_json(SRTWriterConfiguration, json_config_data)
 
     #
     # Construct and configure the writer
